@@ -1,4 +1,7 @@
-import pdb
+try:
+    import ipdb as pdb
+except:
+    import pdb
 
 from Products.SiteErrorLog import SiteErrorLog
 
